# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.
from . import account_edi_format
from . import account_move_send
from . import account_move
from . import certificate
from . import res_company
from . import res_config_settings
